General information (Etopo1 support)
====================================

In order to use the etopo1 data for topography access, please download and store topography data from Etopo dataset within this folder. The data can be downloaded `here <https://www.ngdc.noaa.gov/mgg/global/global.html>`_. You may also store the topography data at another location and provide the path in the code. It will be added automatically into this file, i.e. added to the local search database file LOCAL_TOPO_PATHS.txt which is created on installation within this folder.

Supported Etopo1 files
======================
Tested and supported are the following two files (grid registered):

  1. Ice surface: ETOPO1_Ice_g_gmt4.grd (download `here <https://www.ngdc.noaa.gov/mgg/global/relief/ETOPO1/data/ice_surface/grid_registered/netcdf/ETOPO1_Ice_g_gmt4.grd.gz>`_)
  2. Bedrock: ETOPO1_Bed_g_gmt4.grd (download `here<https://www.ngdc.noaa.gov/mgg/global/relief/ETOPO1/data/bedrock/grid_registered/netcdf/ETOPO1_Bed_g_gmt4.grd.gz>`_)